#! /usr/bin/env python3
# Copyright 2016 to 2021, Cisco Systems, Inc., all rights reserved.
# -*- coding: utf-8 -*-

"""
Common `Sphinx`_ configuration for YANG Suite documentation.

Used for YANG Suite itself and usable for individual apps as well via
``from yangsuite.sphinx_conf import *``

.. _Sphinx:: http://www.sphinx-doc.org
"""

# Note that not all possible configuration values are present in this file.
# All configuration values have a default; values that are commented out
# serve to show the default.

# ####### BEGIN VALUES TO CONFIGURE/OVERRIDE IN YOUR APP ###########

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#   import os
#   import sys
#   sys.path.insert(0, os.path.abspath('app_template'))
#   sys.path.insert(0, os.path.abspath('..'))

# General project information
#   project = 'YANG Suite'
#   copyright = '2017-2019, YANG Suite development team'
#   author = 'YANG Suite development team <yang-suite-dev@cisco.com>'

# Replace with "from MYAPP._version import get_versions"
#   from yangsuite._version import get_versions
#   versioneer_string = get_versions()["version"]
#   # The short X.Y version.
#   version = versioneer_string.split('.post')[0]
#   # The full version, including alpha/beta/rc tags.
#   release = versioneer_string

# Logo image to include in HTML docs
#   html_logo = \
#     "../yangsuite/static/yangsuite/favicon/android-chrome-192x192.png"

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author,
# documentclass [howto, manual, or own class]).
#   latex_documents = [
#       (master_doc, 'YANGSuite.tex', 'YANG Suite Documentation',
#        'Michael Ott', 'manual'),
#   ]


# ####### END VALUES TO CONFIGURE/OVERRIDE IN YOUR APP ###########


# Here and below are configs that should be applicable to most
# yang-suite plugins without any needed changes.

import django
import os
os.environ['DJANGO_SETTINGS_MODULE'] = 'yangsuite.settings.production'
django.setup()

# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
needs_sphinx = '1.7.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.viewcode',
    'sphinx.ext.napoleon',
]

# Add any paths that contain templates here, relative to this directory.
# templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.


# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = [
    '**/_build',
    'Thumbs.db',
    '.DS_Store',
    '**/.tox',
    '**/.venv',
]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars
html_sidebars = {
    '**': [
        'about.html',
        'navigation.html',
        'relations.html',  # needs 'show_related': True theme option to display
        'searchbox.html',
        'donate.html',
    ]
}


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
#   htmlhelp_basename = 'YANGSuitedoc'


# -- Options for LaTeX (and PDF) output -----------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    'pointsize': '12pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
#   man_pages = [
#       (master_doc, 'yangsuite', 'YANG Suite Documentation',
#        [author], 1)
#   ]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
#   texinfo_documents = [
#       (master_doc, 'YANGSuite', 'YANG Suite Documentation',
#        author, 'YANGSuite', 'One line description of project.',
#        'Miscellaneous'),
#   ]

# -- Autodoc configuration ------------------------------------------------

autodoc_default_flags = ['members', 'undoc-members', 'show-inheritance']


# Use intersphinx to link cross-references to other packages
intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
    'django': ('https://docs.djangoproject.com/en/2.0/',
               'https://docs.djangoproject.com/en/2.0/_objects/'),
}

# -- Napoleon configuration -----------------------------------------------

napoleon_use_rtype = False
